#!/usr/bin/env python3
import re
import shutil
import sys
from json import loads
from urllib import request, error

##################
# CONFIG
##################

DUNITER_CONFIG_FILE_PATH = '/home/vit/.config/duniter/duniter_default/conf.json'
DUNITER_CONFIG_FILE_PATH_BACKUP = DUNITER_CONFIG_FILE_PATH + '.back'


def press_key_to_continue():
    # wait for a keypress to end
    input("Press Enter/Return key to quit.")


if __name__ == '__main__':

    # This line will connect to the website, read its contents
    # and parse the JSON output
    response = None
    try:
        response = request.urlopen("https://httpbin.org/get?show_env=1")
    except error.URLError as e:
        print(" Can not get public IP, verify internet connection...")
        press_key_to_continue()
        exit(0)

    content = response.read()
    json = loads(content.decode('utf8'))
    ip = json["headers"]["X-Real-Ip"]
    print("The current public IP is : %s" % ip)

    # check if config is up to date
    if ip in open(DUNITER_CONFIG_FILE_PATH).read():
        print("Duniter config public IP is up to date !")
        press_key_to_continue()
        exit(0)

    # backup Duniter config
    print("copy {0} -> {1}".format(DUNITER_CONFIG_FILE_PATH, DUNITER_CONFIG_FILE_PATH_BACKUP))
    shutil.copyfile(DUNITER_CONFIG_FILE_PATH, DUNITER_CONFIG_FILE_PATH_BACKUP)

    # pattern of an ip adress
    pattern1 = re.compile('(\d+\.\d+\.\d+\.\d+)')

    # change dynamic public ip address with current one

    # Open backup file for reading
    with open(DUNITER_CONFIG_FILE_PATH_BACKUP, "rt") as fin:
        print("open reading " + DUNITER_CONFIG_FILE_PATH_BACKUP)
        # Open config file for writing
        with open(DUNITER_CONFIG_FILE_PATH, "wt") as fout:
            print("open writing " + DUNITER_CONFIG_FILE_PATH)
            # for each line in backup file...
            for line in fin:
                # if config remotehost found...
                if "remotehost" in line:
                    # change dynamic public ip address with current one
                    print("update ws2p remotehost IP : {0}".format(ip))
                    fout.write(pattern1.sub(ip, line))
                # if config remoteipv4 found...
                elif "remoteipv4" in line:
                    # change dynamic public ip address with current one
                    print("udpate bma remoteipv4 IP : {0}".format(ip))
                    fout.write(pattern1.sub(ip, line))
                else:
                    # copy line from backup to config
                    fout.write(line)

    press_key_to_continue()

    exit(0)
